import React, { PropTypes } from 'react'
import { css } from 'glamor'
import cx from 'classnames'
import Box from './Box'
import SearchIcon from './SearchIcon'
import theme from './theme'
import splitProps from './utils/splitProps'
const { minorScale, majorScale } = theme

const styles = css({
  color: theme.backgrounds.white.textColor,
  boxShadow: `inset 0 0 0 1px ${theme.backgrounds.white.borderColor}`,
  '&:focus, &:active': {
    boxShadow: `inset 0 0 0 1px ${theme.colors.primary}`
  }
})

function useControlSizes ({ size, ...props }) {
  const sizes = theme.controlSizes[size]

  return {
    minHeight: sizes.minHeight,
    minWidth: sizes.minWidth,
    textStyle: sizes.textStyle,
    paddingX: size === 'default' ? minorScale(3) : majorScale(2),
    paddingLeft: size === 'default' ? majorScale(4) : majorScale(5),
    ...props
  }
}

const SearchInput = ({ className, ...props }) => {
  // Tries to treat this component as a single box
  const { matchedProps, unmatchedProps } = splitProps(useControlSizes(props),
    /margin|width|height|display/gi)

  return (
    <Box position='relative' display='flex' {...matchedProps}>
      <SearchIcon
        style={{ pointerEvents: 'none' }}
        size='small'
        position='absolute'
        top='50%'
        marginLeft={props.size === 'default' ? minorScale(2) : minorScale(3)}
        marginTop={majorScale(-1)}
      />
      <Box is='input' className={cx(`${styles}`, className)} flex='1' {...unmatchedProps} />
    </Box>
  )
}

SearchInput.propTypes = {
  ...Box.propTypes,
  size: PropTypes.oneOf(Object.keys(theme.controlSizes))
}

SearchInput.defaultProps = {
  circle: true,
  size: 'large'
}

SearchInput.displayName = 'SearchInput'

export default SearchInput
